@@ -2,9 +2,13 @@
 
 import abc
 import contextlib
+import datetime
+import functools
 import importlib
+import json
 import logging
 import logging.config
+import math
 import smtplib
 import sys
 import traceback
@@ -20,6 +24,15 @@ import yaml
 
 log = logging.getLogger(__name__)
 
+class ComplexEncoder(json.JSONEncoder):
+
+    def default(self, obj):
+        try:
+            return super(ComplexEncoder, obj).default(obj)
+
+        except TypeError:
+            return str(obj)
+
 class ConfigWrapper(object):
 
     """
@@ -351,14 +364,27 @@ class ConfigWrapper(object):
         self.__class__.jinja2_environment = j
 
         # Add a bunch of stuff to the template namespace.
+        j.globals['ceil'] = math.ceil
+        j.globals['clepy'] = clepy
+        j.globals['datetime'] = datetime
+        j.globals['dir'] = dir
+        j.globals['enumerate'] = enumerate
+        j.globals['float'] = float
         j.globals['getattr'] = getattr
         j.globals['hasattr'] = hasattr
-        j.globals['clepy'] = clepy
-        j.globals['dir'] = dir
-        j.globals['zip'] = zip
-        j.globals['uuid'] = uuid
+        j.globals['id'] = id
+        j.globals['int'] = int
+        j.globals['json'] = json
+        j.globals['fancyjsondumps'] = functools.partial(json.dumps, cls=ComplexEncoder)
+        j.globals['len'] = len
         j.globals['mathset'] = set
+        j.globals['max'] = max
+        j.globals['round'] = round
         j.globals['sorted'] = sorted
+        j.globals['str'] = str
+        j.globals['type'] = type
+        j.globals['uuid'] = uuid
+        j.globals['zip'] = zip
 
         # Give jinja a reference to the configwrapper.
         j.globals['cw'] = self
